@@ -67,12 +67,13 @@ class Py2NDevice:
             self._info = await get_info(self.aiohttp_session, self.options)
             self._status = await get_status(self.aiohttp_session, self.options)
 
-            self.data = Py2NDeviceData()
-            self.data.name = self._info["deviceName"]
-            self.data.model = self._info["variant"]
-            self.data.serial = self._info["serialNumber"]
-            self.data.firmware = self._info["swVersion"]
-            self.data.uptime = datetime.now() - timedelta(seconds=self._status["upTime"])
+            self.data = Py2NDeviceData(
+                name=self._info["deviceName"],
+                model=self._info["variant"],
+                serial=self._info["serialNumber"],
+                firmware=self._info["swVersion"],
+                uptime=datetime.now() - timedelta(seconds=self._status["upTime"])
+            )
         except InvalidAuthError as err:
             self._last_error = err
             _LOGGER.debug("host %s: error: %r", ip, self._last_error)
