@@ -36,4 +36,4 @@ class Py2NDeviceData:
     model: str
     serial: str
     firmware: str
-    uptime: Optional[datetime]
+    uptime: datetime
